#include <algorithm>
#include <iostream>
#include <iterator>
#include <ranges>
#include <sstream>
#include <string>
#include <vector>

int main() {
	std::string line;
	std::getline(std::cin, line);
	std::istringstream in{ line };

	// old style
	std::vector<int> vec;
	std::copy(std::istream_iterator<int>{ in },
	          {},  // std::istream_iterator<int>{}
		  std::back_inserter(vec));

	std::cout << "---\n";
	std::transform(vec.begin(), vec.end(),
	               std::ostream_iterator<int>{ std::cout, ", " },
		       [](int x) { return 2 * x; });
	std::cout << '\n';

	vec.clear();
	in.clear();
	in.seekg(0);

	// new style
	namespace ranges = std::ranges;
	namespace views = std::views;

	ranges::copy(views::istream<int>(in),
	             std::back_inserter(vec));

	auto twice = vec | views::transform([](int x) { return 2 * x; });

	ranges::copy(twice, std::ostream_iterator<int>{ std::cout, ", " });
	std::cout << '\n';
}
